@@ -1,26 +1,24 @@
 from lxml import etree
 
 
-###########################################################################
-#
-# this module meant to provide intuitive functions to work with xml files
-#
-###########################################################################
+#########################################################################
+# this module aim to provide intuitive functions to work with xml files #
+#########################################################################
 
 
 # will return a list of nodes specified by an attribute key and an attribute value from a parent node
-def get_child_nodes(node_parent, node_tag, node_att_name=None, node_att_val=None, namespace_map=None):
+def get_child_nodes(node_parent, node_tag, node_att_name=None, node_att_val=None, namespace_map=None, filter_comment_nodes=True):
     selector = node_tag
-    return find_all_nodes(node_parent, node_tag, node_att_name, node_att_val, recursive=False, namespace_map=namespace_map)
+    return find_all_nodes(node_parent, node_tag, node_att_name, node_att_val, recursive=False, namespace_map=namespace_map, filter_comment_nodes=filter_comment_nodes)
 
 
 # will search in all of the direct children of the root
-def get_root_direct_child_nodes(xml_file, node_tag, node_att_name=None, node_att_val=None, namespace_map=None):
-    return get_child_nodes(get_root_node(xml_file), node_tag, node_att_name, node_att_val, namespace_map)
+def get_root_direct_child_nodes(xml_file, node_tag, node_att_name=None, node_att_val=None, namespace_map=None, filter_comment_nodes=True):
+    return get_child_nodes(get_root_node(xml_file), node_tag, node_att_name, node_att_val, namespace_map, filter_comment_nodes)
 
 
 # will return a list of nodes which doesn't have a specific attribute
-def get_nodes_from_xml_without_att(xml_file, node_tag, node_att_name=None, namespace_map=None):
+def get_nodes_from_xml_without_att(xml_file, node_tag, node_att_name=None, namespace_map=None, filter_comment_nodes=True):
     root = xml_file.getroot()
     relevant_nodes = []
     node_att_name = _sanitize_att_name(node_att_name, namespace_map)
@@ -28,9 +26,25 @@ def get_nodes_from_xml_without_att(xml_file, node_tag, node_att_name=None, names
     for node in nodes:
         if get_node_att(node, node_att_name) is None:
             relevant_nodes.append(node)
+    if filter_comment_nodes:
+        relevant_nodes = filter_comments(relevant_nodes)
     return relevant_nodes
 
 
+# will remove any comment nodes from a node list
+def filter_comments(node_list):
+    res = []
+    for node in node_list:
+        if not is_comment_node(node):
+            res.append(node)
+    return res
+
+
+# will check if a node is a comment node
+def is_comment_node(node):
+    return type(node) is etree._Comment
+
+
 def nodes_to_dict(nodes, att_key):
     """
     Will turn a list of xml nodes to a dictionary carrying the nodes.
@@ -56,8 +70,11 @@ def nodes_to_dict(nodes, att_key):
 
 
 # will return all of the direct children of a given node
-def get_all_direct_child_nodes(node):
-    return list(node)
+def get_all_direct_child_nodes(node, filter_comment_nodes=True):
+    nodes = list(node)
+    if filter_comment_nodes:
+        return filter_comments(nodes)
+    return nodes
 
 
 # will return the text (inner html) of a given node
@@ -111,7 +128,6 @@ def save_xml_file(xml_file, xml_path, add_utf_8_encoding=False):
 
 # will create an xml file
 def create_xml_file(root_node_tag, output_file):
-
     xml = etree.Element(root_node_tag)
     tree = etree.ElementTree(xml)
 
@@ -183,32 +199,6 @@ def merge_xml1_with_xml2(xml1, xml2):
     return xml1
 
 
-#
-# # will merge xml1 with xml2 and return a new xml comprising both of them.
-# # NOTICE: this function will compare the direct root child nodes and merge/append them.
-# def merge_xml1_with_xml2(xml1, xml2):
-#     xml2_root = get_root_node(xml2)
-#     xml2_direct_children = get_all_direct_child_nodes(xml2_root)
-#     for xml1_child in get_all_direct_child_nodes(get_root_node(xml1)):
-#         parent_node = None
-#         for xml2_child in xml2_direct_children:
-#             # if the direct child already exists, add the appended tag content to the existing one
-#             if xml1_child.tag == xml2_child.tag:
-#                 parent_node = xml2_child
-#                 break
-#
-#         if parent_node is not None:
-#             xml1_direct_children = get_all_direct_child_nodes(xml1_child)
-#             if len(xml1_direct_children) > 0:
-#                 add_nodes(parent_node, xml1_direct_children)
-#             else:
-#                 set_node_text(parent_node, f'{get_text_from_node(xml1_child)}\n{get_text_from_node(parent_node)}')
-#         else:
-#             add_node(xml2_root, xml1_child)
-#
-#     return xml2
-
-
 # Will turn a simple dictionary to an xml file, by hierarchical order
 def simple_dict_to_xml(xml_dict, root_name, output_path, namespace_map=None):
     # will unpack the parent recursively
@@ -236,7 +226,7 @@ def set_node_atts(node, atts_dict, namespace_map=None):
 
 
 # will search for a node
-def find_all_nodes(parent_node, node_tag, node_att_name=None, node_att_val=None, recursive=True, namespace_map=None):
+def find_all_nodes(parent_node, node_tag, node_att_name=None, node_att_val=None, recursive=True, namespace_map=None, filter_comment_nodes=True):
     selector = node_tag
     if node_att_name is not None:
         node_att_name = _sanitize_att_name(node_att_name, namespace_map)
@@ -245,9 +235,12 @@ def find_all_nodes(parent_node, node_tag, node_att_name=None, node_att_val=None,
         else:
             selector = node_tag + "/[@" + node_att_name + "]"
     if recursive:
-        return parent_node.findall(f'.//{selector}')
+        nodes = parent_node.findall(f'.//{selector}')
     else:
-        return parent_node.findall(selector, namespace_map)
+        nodes = parent_node.findall(selector, namespace_map)
+    if filter_comment_nodes:
+        return filter_comments(nodes)
+    return nodes
 
 
 # will parse the namespace, as required, in the att_name
